@@ -17,11 +17,13 @@
 #define USB_DEVICE_ID_RAZER_FIREFLY_V2 0x0C04
 #define USB_DEVICE_ID_RAZER_STRIDER_CHROMA 0x0C05
 #define USB_DEVICE_ID_RAZER_GOLIATHUS_CHROMA_3XL 0x0C06
+#define USB_DEVICE_ID_RAZER_FIREFLY_V2_PRO 0x0C08
 #define USB_DEVICE_ID_RAZER_CHROMA_MUG 0x0F07
 #define USB_DEVICE_ID_RAZER_CHROMA_BASE 0x0F08
 #define USB_DEVICE_ID_RAZER_CHROMA_HDK 0x0F09
 #define USB_DEVICE_ID_RAZER_LAPTOP_STAND_CHROMA 0x0F0D
 #define USB_DEVICE_ID_RAZER_RAPTOR_27 0x0F12
+#define USB_DEVICE_ID_RAZER_TOMAHAWK_ATX 0x0F17
 #define USB_DEVICE_ID_RAZER_KRAKEN_KITTY_EDITION 0x0F19
 #define USB_DEVICE_ID_RAZER_CORE_X_CHROMA 0x0F1A
 #define USB_DEVICE_ID_RAZER_MOUSE_BUNGEE_V3_CHROMA 0x0F1D
